==> ec2-plugin-3.9.0-sources.jar: com/xebialabs/deployit/plugin/ec2/ci/HostTemplate.java <==
package com.xebialabs.deployit.plugin.ec2.ci;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Set;
import java.util.concurrent.TimeoutException;
import com.google.common.collect.Maps;

import com.xebialabs.deployit.plugin.api.flow.Step;
import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem;
import com.xebialabs.deployit.plugin.api.udm.ControlTask;
import com.xebialabs.deployit.plugin.api.udm.Metadata;
import com.xebialabs.deployit.plugin.api.udm.Property;
import com.xebialabs.deployit.plugin.cloud.ci.BaseHostTemplate;
import com.xebialabs.deployit.plugin.cloud.ci.HostParameters;
import com.xebialabs.deployit.plugin.cloud.ci.WaitForInstancesStep;
import com.xebialabs.deployit.plugin.cloud.step.RegisterInstancesStep;
import com.xebialabs.deployit.plugin.cloud.step.ValidateDescriptorStep;
import com.xebialabs.deployit.plugin.cloud.util.CiParser;
import com.xebialabs.deployit.plugin.cloud.util.InstanceDescriptorResolver;
import com.xebialabs.deployit.plugin.cloud.util.MarkerChecker;
import com.xebialabs.deployit.plugin.ec2.access.EC2Adapter;
import com.xebialabs.deployit.plugin.ec2.steps.CreateInstanceStep;
import com.xebialabs.deployit.plugin.ec2.steps.DestroyInstanceStep;
import com.xebialabs.deployit.plugin.ec2.util.EC2InstanceType;
import com.xebialabs.deployit.plugin.ec2.util.ServiceFactory;

import static com.google.common.collect.Lists.newArrayList;

@SuppressWarnings("serial")
@Metadata(description = "Amazon EC2 instance template", root = Metadata.ConfigurationItemRoot.CONFIGURATION)
public class HostTemplate extends BaseHostTemplate {

    @Property(required = true, label = "EC2 credentials", description = "EC2 credentials to be used for creating instances from this template")
    private Credentials credentials;

    @Property(required = true, label = "Groups", description = "Set of security groups to be applied to the instance")
    private Set<String> groups;

    @Property(required = true, label = "Image id (AMI)", description = "Amazon Machine Image id")
    private String ami;

    @Property(required = true, label = "Region", description = "Amazon EC2 region to start instance in", defaultValue = "eu-west-1")
    private String region;

    @Property(required = true, label = "Instance type", description = "Instance type which defines how much resources are allocated")
    private EC2InstanceType instanceType;

    @Property(required = true, label = "Key pair", description = "Name of the key pair (should be already present on EC2)")
    private String keyPair;

    @ControlTask(label = "Instantiate", description = "Create instance from template", parameterType = "cloud.HostParameters")
    public List<? extends Step> instantiate(HostParameters params) {
        return newArrayList(
                new CreateInstanceStep(this, new EC2Adapter(credentials), params.getInstanceName()),
                new WaitForInstancesStep(new MarkerChecker()),
                new RegisterInstancesStep(new InstanceDescriptorResolver(), new CiParser(), params.getHostsLocation())
        );
    }

    @ControlTask(label = "Validate descriptor", description = "Validate XML descriptor")
    public List<? extends Step> validateDescriptor() {

        HashMap<Object,Object> scope = Maps.newHashMap();
        scope.put("hostsPath", "Infrastructure/testHostsLocation");
        scope.put("hostTemplate", this);
        scope.put("cloudId", "myCloudId");
        scope.put("hostAddress", "localhost");

        return newArrayList(new ValidateDescriptorStep(new InstanceDescriptorResolver(), new CiParser(), scope, getXmlDescriptor()));
    }


    public EC2InstanceType getInstanceType() {
        return instanceType;
    }

    public String getKeyPair() {
        return keyPair;
    }


    public Set<String> getGroups() {
        return groups;
    }

    public String getAmi() {
        return ami;
    }

    public String getRegion() {
        return region;
    }

    public void setCredentials(final Credentials credentials) {
        this.credentials = credentials;
    }

    public Credentials getCredentials() {
        return credentials;
    }


    public void setGroups(final Set<String> groups) {
        this.groups = groups;
    }

    public void setAmi(final String ami) {
        this.ami = ami;
    }

    public void setRegion(final String region) {
        this.region = region;
    }

    public void setInstanceType(final EC2InstanceType instanceType) {
        this.instanceType = instanceType;
    }

    public void setKeyPair(final String keyPair) {
        this.keyPair = keyPair;
    }

    @Override
    public List<? extends Step> produceCreateSteps(String environmentTemplateName, int instanceSeq) {
        String instanceLabel = environmentTemplateName + " (" + getName() + ") #" + instanceSeq;
        return Arrays.asList(new CreateInstanceStep(this, new EC2Adapter(getCredentials()), instanceLabel));
    }

    @Override
    public List<? extends Step> produceDestroySteps(ConfigurationItem instance) {
        return Arrays.asList(new DestroyInstanceStep(instance, new ServiceFactory()));
    }

    @Override
    public String getInstanceIpAddress(String cloudId) {
        try {
            return new EC2Adapter(getCredentials())
                    .waitUntilInstanceIsRunning(getRegion(), cloudId, getBootTimeout(), getRetryDelay());
        } catch (TimeoutException e) {
            throw new RuntimeException(e);
        }
    }


}

==> ec2-plugin-3.9.2-sources.jar: com/xebialabs/deployit/plugin/ec2/ci/HostTemplate.java <==
package com.xebialabs.deployit.plugin.ec2.ci;

import java.util.List;
import java.util.Set;
import java.util.concurrent.TimeoutException;

import com.xebialabs.deployit.plugin.api.flow.Step;
import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem;
import com.xebialabs.deployit.plugin.api.udm.Metadata;
import com.xebialabs.deployit.plugin.api.udm.Property;
import com.xebialabs.deployit.plugin.cloud.ci.BaseHostTemplate;
import com.xebialabs.deployit.plugin.cloud.step.WaitForInstancesStep;
import com.xebialabs.deployit.plugin.cloud.util.MarkerChecker;
import com.xebialabs.deployit.plugin.ec2.access.EC2Adapter;
import com.xebialabs.deployit.plugin.ec2.steps.CreateInstanceStep;
import com.xebialabs.deployit.plugin.ec2.steps.DestroyInstanceStep;
import com.xebialabs.deployit.plugin.ec2.util.EC2InstanceType;
import com.xebialabs.deployit.plugin.ec2.util.ServiceFactory;

import static java.util.Arrays.asList;

@SuppressWarnings("serial")
@Metadata(description = "Amazon EC2 instance template", root = Metadata.ConfigurationItemRoot.CONFIGURATION)
public class HostTemplate extends BaseHostTemplate {

    @Property(required = true, label = "EC2 credentials", description = "The EC2 credentials to use when communicating with the AWS API.")
    private Credentials credentials;

    @Property(required = true, label = "Groups", description = "The EC2 security groups to associate with the instance.")
    private Set<String> groups;

    @Property(required = true, label = "Image id (AMI)", description = "The Amazon Machine Image ID (AMI) to use when creating an instance.")
    private String ami;

    @Property(required = true, label = "Region", description = "The EC2 region to create the instance in (e.g., us-west-1 or eu-west-1)")
    private String region;

    @Property(required = true, label = "Instance type", description = "The EC2 instance type to create.")
    private EC2InstanceType instanceType;

    @Property(required = true, label = "Key pair", description = "Name of the EC2 key pair to use. It should be already present on EC2.")
    private String keyPair;

    public EC2InstanceType getInstanceType() {
        return instanceType;
    }

    public String getKeyPair() {
        return keyPair;
    }


    public Set<String> getGroups() {
        return groups;
    }

    public String getAmi() {
        return ami;
    }

    public String getRegion() {
        return region;
    }

    public void setCredentials(final Credentials credentials) {
        this.credentials = credentials;
    }

    public Credentials getCredentials() {
        return credentials;
    }


    public void setGroups(final Set<String> groups) {
        this.groups = groups;
    }

    public void setAmi(final String ami) {
        this.ami = ami;
    }

    public void setRegion(final String region) {
        this.region = region;
    }

    public void setInstanceType(final EC2InstanceType instanceType) {
        this.instanceType = instanceType;
    }

    public void setKeyPair(final String keyPair) {
        this.keyPair = keyPair;
    }

    @Override
    public List<? extends Step> produceCreateSteps(String name, int instanceSeq) {
        String instanceLabel = instanceSeq == 0 ? name : name + " (" + getName() + ") #" + instanceSeq;
        return asList(new CreateInstanceStep(this, new EC2Adapter(getCredentials()), instanceLabel), new WaitForInstancesStep(new MarkerChecker()));
    }

    @Override
    public List<? extends Step> produceDestroySteps(ConfigurationItem instance) {
        return asList(new DestroyInstanceStep(instance, new ServiceFactory()));
    }

    @Override
    public String getInstanceIpAddress(String cloudId) {
        try {
            return new EC2Adapter(getCredentials())
                    .waitUntilInstanceIsRunning(getRegion(), cloudId, getBootTimeout(), getRetryDelay());
        } catch (TimeoutException e) {
            throw new RuntimeException(e);
        }
    }


}
